Struct BlockIndex

pub struct BlockIndex { /* private fields */ }
A block index that is tied to a specific ChainstateManager.

Internally the ChainstateManager keeps an in-memory of the current block tree once it is loaded. The BlockIndex points to an entry in this tree. It is only valid as long as the ChainstateManager it was retrieved from remains in scope.

Implementations

Source

impl BlockIndex

pub fn prev(self) -> Result<BlockIndex, KernelError>

Move to the previous entry in the block tree. E.g. from height n to height n-1.

pub fn height(&self) -> i32

Get the current height associated with this BlockIndex.

pub fn block_hash(&self) -> BlockHash

Get the current block hash associated with this BlockIndex.