Struct ChainstateManagerOptions

pub struct ChainstateManagerOptions { /* private fields */ }
Holds the configuration options for creating a new ChainstateManager

Implementations

Source

impl ChainstateManagerOptions

pub fn new( context: &Context, data_dir: &str, blocks_dir: &str, ) -> Result<Self, KernelError>

Create a new option

Arguments
pub fn set_worker_threads(&self, worker_threads: i32)

Set the number of worker threads used by script validation

pub fn set_wipe_db(self, wipe_block_tree: bool, wipe_chainstate: bool) -> Self

Wipe the block tree or chainstate dbs. When wiping the block tree db the chainstate db has to be wiped too. Wiping the databases will triggere a rebase once import blocks is called.

pub fn set_block_tree_db_in_memory(self, block_tree_db_in_memory: bool) -> Self

Run the block tree db in-memory only. No database files will be written to disk.

pub fn set_chainstate_db_in_memory(self, chainstate_db_in_memory: bool) -> Self

Run the chainstate db in-memory only. No database files will be written to disk.