pub struct TxOut { /* private fields */ }Expand description
A single transaction output.
It can be initialized with a script pubkey and amount, and the user may retrieve a copy of a script pubkey and its amount.
Implementations
Sourceimpl TxOut
impl TxOut
pub fn new(script_pubkey: &ScriptPubkey, amount: i64) -> TxOut
Sourcepub fn get_script_pubkey(&self) -> ScriptPubkey
pub fn get_script_pubkey(&self) -> ScriptPubkey
Get the script pubkey of this output