pub trait WarningUnset: Fn(KernelWarning) { }Expand description
A previous condition leading to the issuance of a warning is no longer given.
pub trait WarningUnset: Fn(KernelWarning) { }A previous condition leading to the issuance of a warning is no longer given.