pub struct BlockIndex { /* private fields */ }Expand description
A block index that is tied to a specific ChainstateManager.
Internally the ChainstateManager keeps an in-memory of the current block
tree once it is loaded. The BlockIndex points to an entry in this tree.
It is only valid as long as the ChainstateManager it was retrieved from
remains in scope.
Implementations
Sourceimpl BlockIndex
impl BlockIndex
Sourcepub fn prev(self) -> Result<BlockIndex, KernelError>
pub fn prev(self) -> Result<BlockIndex, KernelError>
Move to the previous entry in the block tree. E.g. from height n to height n-1.
Sourcepub fn block_hash(&self) -> BlockHash
pub fn block_hash(&self) -> BlockHash
Get the current block hash associated with this BlockIndex.